__author__ = 'AJ McKenna, https://github.com/amckenna41'
__authorEmail__ = 'amckenna41@qub.ac.uk'
__url__ = 'https://github.com/amckenna41/pyWikiCommons'
__credits__ = ['AJ McKenna']
__version__ = "0.0.2"
__license__ = 'MIT'
__name__ = 'pyWikiCommons'
__status__ = 'Development'
__maintainer__ = "AJ McKenna"

from pyWikiCommons import *